==> flutter_nearby_messages_api-0.0.3.tar.gz: lib/flutter_nearby_messages_api.dart <==
import 'dart:async';

import 'package:flutter/services.dart';

typedef void FlutterNearbyMessagesCallback(dynamic message);
typedef void FlutterNearbyStatusHandlerCallback(GNSOperationStatus status);

enum GNSOperationStatus { inactive, starting, active }

class FlutterNearbyMessagesApi {
  static const MethodChannel _channel =
      const MethodChannel('flutter_nearby_messages_api');

  FlutterNearbyMessagesCallback onFound;
  FlutterNearbyMessagesCallback onLost;
  FlutterNearbyStatusHandlerCallback statusHandler;

  FlutterNearbyMessagesApi() {
    _channel.setMethodCallHandler((MethodCall call) async {
      switch (call.method) {
        case 'onFound':
          return onFound(call.arguments);
        case 'onLost':
          return onLost(call.arguments);
        case 'statusHandler':
          final status = int.parse(call.arguments.toString());

          if (status != null) {
            switch (status) {
              case 1:
                statusHandler(GNSOperationStatus.starting);
                break;
              case 2:
                statusHandler(GNSOperationStatus.active);
                break;
              default:
                statusHandler(GNSOperationStatus.inactive);
                break;
            }
          }
          break;
        default:
          throw MissingPluginException();
      }
    });
  }

  Future<void> setAPIKey(String key) async {
    await _channel.invokeMethod('setAPIKey', {'apikey': key});
  }

  Future<void> publish(String message) async {
    await _channel.invokeMethod('publish', {'message': message});
  }

  Future<void> setGranted() async {
    await _channel.invokeMethod('setGranted', {'isGranted': true});
  }

  Future<void> unPublish() async {
    await _channel.invokeMethod('unPublish');
  }

  Future<void> backgroundSubscribe() async {
    await _channel.invokeMethod('backgroundSubscribe');
  }

  Future<void> backgroundUnsubscribe() async {
    onFound = null;
    onLost = null;
    await _channel.invokeMethod('backgroundUnsubscribe');
  }

  Future<void> enableDebugMode() async {
    await _channel.invokeMethod('enableDebugMode');
  }

  Future<void> disableDebugMode() async {
    await _channel.invokeMethod('disableDebugMode');
  }
}

==> flutter_nearby_messages_api-0.0.5.tar.gz: lib/flutter_nearby_messages_api.dart <==
import 'dart:async';

import 'package:flutter/services.dart';

typedef void FlutterNearbyMessagesCallback(dynamic message);
typedef void FlutterNearbyStatusHandlerCallback(GNSOperationStatus status);
typedef void FlutterNearbyPermissionStatusHandlerCallback(
    GNSPermissionStatus status);

enum GNSOperationStatus { inactive, starting, active }
enum GNSPermissionStatus { deny, granted }

class FlutterNearbyMessagesApi {
  static const MethodChannel _channel =
      const MethodChannel('flutter_nearby_messages_api');

  FlutterNearbyMessagesCallback onFound;
  FlutterNearbyMessagesCallback onLost;
  FlutterNearbyStatusHandlerCallback statusHandler;

  FlutterNearbyStatusHandlerCallback microphonePermissionErrorHandler;
  FlutterNearbyStatusHandlerCallback bluetoothPowerErrorHandler;
  FlutterNearbyStatusHandlerCallback bluetoothPermissionErrorHandler;
  FlutterNearbyPermissionStatusHandlerCallback permissionHandler;

  FlutterNearbyMessagesApi() {
    _channel.setMethodCallHandler((MethodCall call) async {
      switch (call.method) {
        case 'onFound':
          return onFound(call.arguments);
        case 'onLost':
          return onLost(call.arguments);
        case 'statusHandler':
          final status = int.parse(call.arguments.toString());

          if (status != null) {
            switch (status) {
              case 1:
                statusHandler(GNSOperationStatus.starting);
                break;
              case 2:
                statusHandler(GNSOperationStatus.active);
                break;
              default:
                statusHandler(GNSOperationStatus.inactive);
                break;
            }
          }
          break;
        case 'microphonePermissionErrorHandler':
          return microphonePermissionErrorHandler(GNSOperationStatus.inactive);
        case 'bluetoothPowerErrorHandler':
          return bluetoothPowerErrorHandler(GNSOperationStatus.inactive);
        case 'bluetoothPermissionErrorHandler':
          return bluetoothPermissionErrorHandler(GNSOperationStatus.inactive);
        case 'permissionHandler':
          final status = int.parse(call.arguments.toString());

          if (status != null) {
            switch (status) {
              case 1:
                permissionHandler(GNSPermissionStatus.granted);
                break;
              default:
                permissionHandler(GNSPermissionStatus.deny);
                break;
            }
          }
          break;
        default:
          throw MissingPluginException();
      }
    });
  }

  Future<void> setAPIKey(String key) async {
    await _channel.invokeMethod('setAPIKey', {'apikey': key});
  }

  Future<void> setPermissionAlert(
      String title, String message, String denyText, String grantText) async {
    await _channel.invokeMethod('setPermissionAlert', {
      'title_text': title,
      'message_text': message,
      'deny_text': denyText,
      'grant_text': grantText
    });
  }

  Future<void> publish(String message) async {
    await _channel.invokeMethod('publish', {'message': message});
  }

  Future<void> setNearbyAccessPermission(bool value) async {
    await _channel.invokeMethod('setNearbyAccessPermission', {'value': value});
  }

  Future<void> unPublish() async {
    await _channel.invokeMethod('unPublish');
  }

  Future<void> backgroundSubscribe() async {
    await _channel.invokeMethod('backgroundSubscribe');
  }

  Future<void> backgroundUnsubscribe() async {
    onFound = null;
    onLost = null;
    await _channel.invokeMethod('backgroundUnsubscribe');
  }

  Future<void> enableDebugMode() async {
    await _channel.invokeMethod('enableDebugMode');
  }

  Future<void> disableDebugMode() async {
    await _channel.invokeMethod('disableDebugMode');
  }
}
